use utf8;

{
  'файл топиков'=> 'static-share.dirs.txt', # в 'админка папка'
  'админка адрес'=>'/админ',
  'админка папка'=>'t',#/mnt/sda/
  'админка пароль'=>'123123',# 111-333+159
  'шаблоны папка'=>'шаблоны',# в 'админка папка' '/mnt/sda/шаблоны'
  'корень папка'=>'корень',
  mojo=>{
    hypnotoad => {listen => ["http://*:3003"], pid_file => "t/static-share-hypnotoad.pid", workers000 => 1,},
    secrets => ['21--332++34'],
  },

};
